Stan Math Library: stan/math/prim/scal/fun/logical_negation.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

logical_negation.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_LOGICAL_NEGATION_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_LOGICAL_NEGATION_HPP
3
4 namespace stan {
5 namespace math {
6
15 template <typename T>
16 inline int
17 logical_negation(const T x) {
18 return (x == 0);
19 }
20
21 }
22 }
23
24 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::logical_negation
int logical_negation(const T x)
The logical negation function which returns 1 if the input is equal to zero and 0 otherwise...
Definition: logical_negation.hpp:17

[ Stan Home Page ] © 2011–2016, Stan Development Team.